# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Labs(str, enum.Enum):
    AYUMETRIX = "ayumetrix"
    SPIRIPLEX = "spiriplex"
    USSL = "ussl"
    QUEST = "quest"
    LABCORP = "labcorp"
    BIOREFERENCE = "bioreference"
    MANUAL = "manual"
    SANOCARDIO = "sanocardio"

    def visit(
        self,
        ayumetrix: typing.Callable[[], T_Result],
        spiriplex: typing.Callable[[], T_Result],
        ussl: typing.Callable[[], T_Result],
        quest: typing.Callable[[], T_Result],
        labcorp: typing.Callable[[], T_Result],
        bioreference: typing.Callable[[], T_Result],
        manual: typing.Callable[[], T_Result],
        sanocardio: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Labs.AYUMETRIX:
            return ayumetrix()
        if self is Labs.SPIRIPLEX:
            return spiriplex()
        if self is Labs.USSL:
            return ussl()
        if self is Labs.QUEST:
            return quest()
        if self is Labs.LABCORP:
            return labcorp()
        if self is Labs.BIOREFERENCE:
            return bioreference()
        if self is Labs.MANUAL:
            return manual()
        if self is Labs.SANOCARDIO:
            return sanocardio()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .client_facing_source import ClientFacingSource
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ClientFacingBody(UniversalBaseModel):
    user_id: str = pydantic.Field()
    """
    User id returned by vital create user request. This id should be stored in your database against the user and used for all interactions with the vital api.
    """

    id: str
    date: str = pydantic.Field()
    """
    Date of the specified record, formatted as ISO8601 datetime string in UTC 00:00. Deprecated in favour of calendar_date.
    """

    calendar_date: str = pydantic.Field()
    """
    Date of the summary in the YYYY-mm-dd format.
    """

    weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Weight in kg::kg
    """

    fat: typing.Optional[float] = pydantic.Field(default=None)
    """
    Body fat percentage::perc
    """

    source: ClientFacingSource

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .gender import Gender
from .address import Address
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class PersonDetailsOutput(UniversalBaseModel):
    first_name: str
    last_name: str
    gender: Gender
    address: Address
    dob: str
    email: str
    phone_number: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class IndexColumnExprIndex(str, enum.Enum):
    SLEEP = "sleep"
    ACTIVITY = "activity"

    def visit(self, sleep: typing.Callable[[], T_Result], activity: typing.Callable[[], T_Result]) -> T_Result:
        if self is IndexColumnExprIndex.SLEEP:
            return sleep()
        if self is IndexColumnExprIndex.ACTIVITY:
            return activity()



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .connection_status_state import ConnectionStatusState
import typing
from .provider_mfa_request import ProviderMfaRequest
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConnectionStatus(UniversalBaseModel):
    state: ConnectionStatusState
    redirect_url: typing.Optional[str] = None
    error_type: typing.Optional[str] = None
    error: typing.Optional[str] = None
    provider_mfa: typing.Optional[ProviderMfaRequest] = None
    success: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .aggregate_expr import AggregateExpr
from .sleep_column_expr import SleepColumnExpr
from .activity_column_expr import ActivityColumnExpr
from .index_column_expr import IndexColumnExpr
from .group_key_column_expr import GroupKeyColumnExpr

QueryInstructionSelectItem = typing.Union[
    AggregateExpr, SleepColumnExpr, ActivityColumnExpr, IndexColumnExpr, GroupKeyColumnExpr
]
